pub struct ValueKey(/* private fields */);Trait Implementations
impl Copy for ValueKey
Sourceimpl<'de> Deserialize<'de> for ValueKey
impl<'de> Deserialize<'de> for ValueKey
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ValueKey
Sourceimpl Key for ValueKey
impl Key for ValueKey
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for ValueKey
impl Ord for ValueKey
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ValueKey
impl PartialOrd for ValueKey
impl StructuralPartialEq for ValueKey